Bandwidth class

Describes bandwidth information.

Constructors

Bandwidth({int? downloadSpeed, int? uploadSpeed})
Bandwidth.fromJson(Map<String, dynamic> json)
factory

Properties

downloadSpeed → int?
Download speed in Mbps.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadSpeed → int?
Upload speed in Mbps.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited