Connection class

Describes a connection.

Constructors

Connection({String? connectedDeviceId, String? connectedLinkId, String? connectionArn, String? connectionId, DateTime? createdAt, String? description, String? deviceId, String? globalNetworkId, String? linkId, ConnectionState? state, List<Tag>? tags})
Connection.fromJson(Map<String, dynamic> json)
factory

Properties

connectedDeviceId → String?
The ID of the second device in the connection.
final
connectedLinkId → String?
The ID of the link for the second device in the connection.
final
connectionArn → String?
The Amazon Resource Name (ARN) of the connection.
final
connectionId → String?
The ID of the connection.
final
createdAt → DateTime?
The date and time that the connection was created.
final
description → String?
The description of the connection.
final
deviceId → String?
The ID of the first device in the connection.
final
globalNetworkId → String?
The ID of the global network.
final
hashCode → int
The hash code for this object.
no setterinherited
linkId → String?
The ID of the link for the first device in the connection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ConnectionState?
The state of the connection.
final
tags → List<Tag>?
The tags for the connection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited