Device class

Describes a device.

Constructors

Device({AWSLocation? awsLocation, DateTime? createdAt, String? description, String? deviceArn, String? deviceId, String? globalNetworkId, Location? location, String? model, String? serialNumber, String? siteId, DeviceState? state, List<Tag>? tags, String? type, String? vendor})
Device.fromJson(Map<String, dynamic> json)
factory

Properties

awsLocation → AWSLocation?
The AWS location of the device.
final
createdAt → DateTime?
The date and time that the site was created.
final
description → String?
The description of the device.
final
deviceArn → String?
The Amazon Resource Name (ARN) of the device.
final
deviceId → String?
The ID of the device.
final
globalNetworkId → String?
The ID of the global network.
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location?
The site location.
final
model → String?
The device model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
The device serial number.
final
siteId → String?
The site ID.
final
state → DeviceState?
The device state.
final
tags → List<Tag>?
The tags for the device.
final
type → String?
The device type.
final
vendor → String?
The device vendor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited