GetDevicesResponse class

Constructors

GetDevicesResponse({List<Device>? devices, String? nextToken})
GetDevicesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

devices → List<Device>?
The devices.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token for the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited