GlobalNetwork class

Describes a global network.

Constructors

GlobalNetwork({DateTime? createdAt, String? description, String? globalNetworkArn, String? globalNetworkId, GlobalNetworkState? state, List<Tag>? tags})
GlobalNetwork.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The date and time that the global network was created.
final
description → String?
The description of the global network.
final
globalNetworkArn → String?
The Amazon Resource Name (ARN) of the global network.
final
globalNetworkId → String?
The ID of the global network.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → GlobalNetworkState?
The state of the global network.
final
tags → List<Tag>?
The tags for the global network.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited