Link class

Describes a link.

Constructors

Link({Bandwidth? bandwidth, DateTime? createdAt, String? description, String? globalNetworkId, String? linkArn, String? linkId, String? provider, String? siteId, LinkState? state, List<Tag>? tags, String? type})
Link.fromJson(Map<String, dynamic> json)
factory

Properties

bandwidth → Bandwidth?
The bandwidth for the link.
final
createdAt → DateTime?
The date and time that the link was created.
final
description → String?
The description of the link.
final
globalNetworkId → String?
The ID of the global network.
final
hashCode → int
The hash code for this object.
no setterinherited
linkArn → String?
The Amazon Resource Name (ARN) of the link.
final
linkId → String?
The ID of the link.
final
provider → String?
The provider of the link.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteId → String?
The ID of the site.
final
state → LinkState?
The state of the link.
final
tags → List<Tag>?
The tags for the link.
final
type → String?
The type of the link.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited