LinkAssociation class

Describes the association between a device and a link.

Constructors

LinkAssociation({String? deviceId, String? globalNetworkId, LinkAssociationState? linkAssociationState, String? linkId})
LinkAssociation.fromJson(Map<String, dynamic> json)
factory

Properties

deviceId → String?
The device ID for the link association.
final
globalNetworkId → String?
The ID of the global network.
final
hashCode → int
The hash code for this object.
no setterinherited
linkAssociationState → LinkAssociationState?
The state of the association.
final
linkId → String?
The ID of the link.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited